@@ -1,15 +1,19 @@
-use crate::parse_instruction::{
-    check_num_accounts, ParsableProgram, ParseInstructionError, ParsedInstructionEnum,
-};
-use serde_json::{json, Map, Value};
-use solana_account_decoder::parse_token::{pubkey_from_spl_token_v2_0, token_amount_to_ui_amount};
-use solana_sdk::{
-    instruction::{AccountMeta, CompiledInstruction, Instruction},
-    pubkey::Pubkey,
-};
-use spl_token_v2_0::{
-    instruction::{AuthorityType, TokenInstruction},
-    solana_program::{instruction::Instruction as SplTokenInstruction, program_option::COption},
+use {
+    crate::parse_instruction::{
+        check_num_accounts, ParsableProgram, ParseInstructionError, ParsedInstructionEnum,
+    },
+    serde_json::{json, Map, Value},
+    solana_account_decoder::parse_token::{pubkey_from_spl_token_v2_0, token_amount_to_ui_amount},
+    solana_sdk::{
+        instruction::{AccountMeta, CompiledInstruction, Instruction},
+        pubkey::Pubkey,
+    },
+    spl_token_v2_0::{
+        instruction::{AuthorityType, TokenInstruction},
+        solana_program::{
+            instruction::Instruction as SplTokenInstruction, program_option::COption,
+        },
+    },
 };
 
 pub fn parse_token(
@@ -452,16 +456,18 @@ pub fn spl_token_v2_0_instruction(instruction: SplTokenInstruction) -> Instructi
 
 #[cfg(test)]
 mod test {
-    use super::*;
-    use solana_sdk::instruction::CompiledInstruction;
-    use spl_token_v2_0::{
-        instruction::*,
-        solana_program::{
-            instruction::CompiledInstruction as SplTokenCompiledInstruction, message::Message,
-            pubkey::Pubkey as SplTokenPubkey,
+    use {
+        super::*,
+        solana_sdk::instruction::CompiledInstruction,
+        spl_token_v2_0::{
+            instruction::*,
+            solana_program::{
+                instruction::CompiledInstruction as SplTokenCompiledInstruction, message::Message,
+                pubkey::Pubkey as SplTokenPubkey,
+            },
         },
+        std::str::FromStr,
     };
-    use std::str::FromStr;
 
     fn convert_pubkey(pubkey: Pubkey) -> SplTokenPubkey {
         SplTokenPubkey::from_str(&pubkey.to_string()).unwrap()
