@@ -1,14 +1,19 @@
-use crate::TransactionTokenBalance;
-use solana_account_decoder::parse_token::{
-    spl_token_id_v2_0, spl_token_v2_0_native_mint, token_amount_to_ui_amount, UiTokenAmount,
+use {
+    crate::TransactionTokenBalance,
+    solana_account_decoder::parse_token::{
+        pubkey_from_spl_token_v2_0, spl_token_id_v2_0, spl_token_v2_0_native_mint,
+        token_amount_to_ui_amount, UiTokenAmount,
+    },
+    solana_measure::measure::Measure,
+    solana_metrics::datapoint_debug,
+    solana_runtime::{bank::Bank, transaction_batch::TransactionBatch},
+    solana_sdk::{account::ReadableAccount, pubkey::Pubkey},
+    spl_token_v2_0::{
+        solana_program::program_pack::Pack,
+        state::{Account as TokenAccount, Mint},
+    },
+    std::collections::HashMap,
 };
-use solana_runtime::{bank::Bank, transaction_batch::TransactionBatch};
-use solana_sdk::{account::ReadableAccount, pubkey::Pubkey};
-use spl_token_v2_0::{
-    solana_program::program_pack::Pack,
-    state::{Account as TokenAccount, Mint},
-};
-use std::{collections::HashMap, str::FromStr};
 
 pub type TransactionTokenBalances = Vec<Vec<TransactionTokenBalance>>;
 
@@ -54,6 +59,7 @@ pub fn collect_token_balances(
     mut mint_decimals: &mut HashMap<Pubkey, u8>,
 ) -> TransactionTokenBalances {
     let mut balances: TransactionTokenBalances = vec![];
+    let mut collect_time = Measure::start("collect_token_balances");
 
     for transaction in batch.transactions_iter() {
         let account_keys = &transaction.message.account_keys;
@@ -68,41 +74,56 @@ pub fn collect_token_balances(
                     continue;
                 }
 
-                if let Some((mint, ui_token_amount)) =
-                    collect_token_balance_from_account(bank, account_id, &mut mint_decimals)
+                if let Some(TokenBalanceData {
+                    mint,
+                    ui_token_amount,
+                    owner,
+                }) = collect_token_balance_from_account(bank, account_id, &mut mint_decimals)
                 {
                     transaction_balances.push(TransactionTokenBalance {
                         account_index: index as u8,
                         mint,
                         ui_token_amount,
+                        owner,
                     });
                 }
             }
         }
         balances.push(transaction_balances);
     }
+    collect_time.stop();
+    datapoint_debug!(
+        "collect_token_balances",
+        ("collect_time_us", collect_time.as_us(), i64),
+    );
     balances
 }
 
-pub fn collect_token_balance_from_account(
+struct TokenBalanceData {
+    mint: String,
+    owner: String,
+    ui_token_amount: UiTokenAmount,
+}
+
+fn collect_token_balance_from_account(
     bank: &Bank,
     account_id: &Pubkey,
     mint_decimals: &mut HashMap<Pubkey, u8>,
-) -> Option<(String, UiTokenAmount)> {
+) -> Option<TokenBalanceData> {
     let account = bank.get_account(account_id)?;
 
     let token_account = TokenAccount::unpack(account.data()).ok()?;
-    let mint_string = &token_account.mint.to_string();
-    let mint = &Pubkey::from_str(mint_string).unwrap_or_default();
+    let mint = pubkey_from_spl_token_v2_0(&token_account.mint);
 
-    let decimals = mint_decimals.get(mint).cloned().or_else(|| {
-        let decimals = get_mint_decimals(bank, mint)?;
-        mint_decimals.insert(*mint, decimals);
+    let decimals = mint_decimals.get(&mint).cloned().or_else(|| {
+        let decimals = get_mint_decimals(bank, &mint)?;
+        mint_decimals.insert(mint, decimals);
         Some(decimals)
     })?;
 
-    Some((
-        mint_string.to_string(),
-        token_amount_to_ui_amount(token_account.amount, decimals),
-    ))
+    Some(TokenBalanceData {
+        mint: token_account.mint.to_string(),
+        owner: token_account.owner.to_string(),
+        ui_token_amount: token_amount_to_ui_amount(token_account.amount, decimals),
+    })
 }
